@@ -440,8 +440,13 @@ class Locale(object):
                                  self.langData['en_US'])[field]
 
     def getLangByField(self, field, value):
+        if field == 'locale':
+            value = (value,value.replace('UTF-8','utf8'))
+        else:
+            value = (value,)
+
         langs = [lang[0] for lang in self.langData.items()
-                 if lang[1][field] == value]
+                 if lang[1][field] in value]
         if not langs:
             return 'en_US'
         else:
@@ -484,6 +489,7 @@ class VariableOsLocaleLocale(ReadonlyVariable, Locale):
         else:
             cmd_val = None
         locale_val = getValueFromConfig(locale_file, self.env_var)
+        locale_val = locale_val.replace('UTF-8','utf8')
         if self.isValueInFieldExists('locale', locale_val):
             file_val = locale_val
         else:
